pub struct State {
pub input_name: String,
pub output_name: String,
pub data_type: i32,
pub dims: Vec<i64>,
pub initial_state: Vec<InitialState>,
}Expand description
@@ .. cpp:var:: message State @@ @@ An input / output pair of tensors that carry state for the sequence. @@
Fields
input_name: String@@ .. cpp:var:: string input_name @@ @@ The name of the model state input. @@
output_name: String@@ .. cpp:var:: string output_name @@ @@ The name of the model state output. @@
data_type: i32@@ .. cpp:var:: DataType data_type @@ @@ The data-type of the state. @@
dims: Vec<i64>@@ .. cpp:var:: int64 dim (repeated) @@ @@ The dimension. @@
initial_state: Vec<InitialState>@@ .. cpp:var:: InitialState initial_state (repeated) @@ @@ The optional field to specify the initial state for the model. @@
Implementations