pub struct StrategyDirect {
pub max_queue_delay_microseconds: u64,
pub minimum_slot_utilization: f32,
}Expand description
@@ .. cpp:var:: message StrategyDirect @@ @@ The sequence batcher uses a specific, unique batch @@ slot for each sequence. All inference requests in a @@ sequence are directed to the same batch slot in the same @@ model instance over the lifetime of the sequence. This @@ is the default strategy. @@
Fields
max_queue_delay_microseconds: u64@@ .. cpp:var:: uint64 max_queue_delay_microseconds @@ @@ The maximum time, in microseconds, a candidate request @@ will be delayed in the sequence batch scheduling queue to @@ wait for additional requests for batching. Default is 0. @@
minimum_slot_utilization: f32@@ .. cpp:var:: float minimum_slot_utilization @@ @@ The minimum slot utilization that must be satisfied to @@ execute the batch before ‘max_queue_delay_microseconds’ expires. @@ For example, a value of 0.5 indicates that the batch should be @@ executed as soon as 50% or more of the slots are ready even if @@ the ‘max_queue_delay_microseconds’ timeout has not expired. @@ The default is 0.0, indicating that a batch will be executed @@ before ‘max_queue_delay_microseconds’ timeout expires if at least @@ one batch slot is ready. ‘max_queue_delay_microseconds’ will be @@ ignored unless minimum_slot_utilization is set to a non-zero @@ value. @@