pub struct ModelQueuePolicy {
pub timeout_action: i32,
pub default_timeout_microseconds: u64,
pub allow_timeout_override: bool,
pub max_queue_size: u32,
}Expand description
@@ @@.. cpp:var:: message ModelQueuePolicy @@ @@ Queue policy for inference requests. @@
Fields
timeout_action: i32@@ @@ .. cpp:var:: TimeoutAction timeout_action @@ @@ The action applied to timed-out request. @@ The default action is REJECT. @@
default_timeout_microseconds: u64@@ @@ .. cpp:var:: uint64 default_timeout_microseconds @@ @@ The default timeout for every request, in microseconds. @@ The default value is 0 which indicates that no timeout is set. @@
allow_timeout_override: bool@@ @@ .. cpp:var:: bool allow_timeout_override @@ @@ Whether individual request can override the default timeout value. @@ When true, individual requests can set a timeout that is less than @@ the default timeout value but may not increase the timeout. @@ The default value is false. @@
max_queue_size: u32@@ @@ .. cpp:var:: uint32 max_queue_size @@ @@ The maximum queue size for holding requests. A request will be @@ rejected immediately if it can’t be enqueued because the queue is @@ full. The default value is 0 which indicates that no maximum @@ queue size is enforced. @@
Implementations
Sourceimpl ModelQueuePolicy
impl ModelQueuePolicy
Sourcepub fn timeout_action(&self) -> TimeoutAction
pub fn timeout_action(&self) -> TimeoutAction
Returns the enum value of timeout_action, or the default if the field is set to an invalid enum value.
Sourcepub fn set_timeout_action(&mut self, value: TimeoutAction)
pub fn set_timeout_action(&mut self, value: TimeoutAction)
Sets timeout_action to the provided enum value.