pub struct ModelSequenceBatching {
pub max_sequence_idle_microseconds: u64,
pub control_input: Vec<ControlInput>,
pub state: Vec<State>,
pub strategy_choice: Option<StrategyChoice>,
}Expand description
@@ @@.. cpp:var:: message ModelSequenceBatching @@ @@ Sequence batching configuration. These settings control how sequence @@ batching operates for the model. @@
Fields
max_sequence_idle_microseconds: u64@@ .. cpp:var:: uint64 max_sequence_idle_microseconds @@ @@ The maximum time, in microseconds, that a sequence is allowed to @@ be idle before it is aborted. The inference server considers a @@ sequence idle when it does not have any inference request queued @@ for the sequence. If this limit is exceeded, the inference server @@ will free the sequence slot allocated by the sequence and make it @@ available for another sequence. If not specified (or specified as @@ zero) a default value of 1000000 (1 second) is used. @@
control_input: Vec<ControlInput>@@ .. cpp:var:: ControlInput control_input (repeated) @@ @@ The model input(s) that the server should use to communicate @@ sequence start, stop, ready and similar control values to the @@ model. @@
state: Vec<State>@@ .. cpp:var:: State state (repeated) @@ @@ The optional state that can be stored in Triton for performing @@ inference requests on a sequence. Each sequence holds an implicit @@ state local to itself. The output state tensor provided by the @@ model in ‘output_name’ field of the current inference request will @@ be transferred as an input tensor named ‘input_name’ in the next @@ request of the same sequence. The input state of the first request @@ in the sequence contains garbage data. @@
strategy_choice: Option<StrategyChoice>@@ .. cpp:var:: oneof strategy_choice @@ @@ The strategy used by the sequence batcher. Default strategy @@ is ‘direct’. @@