pub struct SystemSharedMemoryRegisterRequest {
pub name: String,
pub key: String,
pub offset: u64,
pub byte_size: u64,
}Expand description
@@ @@.. cpp:var:: message SystemSharedMemoryRegisterRequest @@ @@ Request message for SystemSharedMemoryRegister. @@
Fields
name: String@@ @@ .. cpp:var:: string name @@ @@ The name of the region to register. @@
key: String@@ .. cpp:var:: string shared_memory_key @@ @@ The key of the underlying memory object that contains the @@ shared memory region. @@
offset: u64@@ .. cpp:var:: uint64 offset @@ @@ Offset, in bytes, within the underlying memory object to @@ the start of the shared memory region. @@
byte_size: u64@@ .. cpp:var:: uint64 byte_size @@ @@ Size of the shared memory region, in bytes. @@